import Qt 4.7
import QtWebKit 1.0
import "imports/XAComponents"
import "imports/XAComponents/date.js" as DateFunctions
import "imports/WebBrowserContent"
import "imports/colibri"
import "Inspector"

Item {
    id: maincomponent
    width: 480
    height: 240
    anchors.fill: parent

    property alias text : textField.text
    property string windowTitle : qtInputTitle
    property string windowGotFocus : qtWindowGotFocus
    property string windowDisplaysItemOfType: qtItemType
    property string windowDisplaysItemWithUID: qtItemUID
    property string platformID: qtPlatformID

    property string itemTitle: qtItemTitle
    property string itemDTSHR: qtItemDTSHR
    property string itemContextHR: qtItemContextHR

    property color tabPanelMarkerColor: "#d9d9d9"
    property Gradient tabPanelBackgroundGradient: Gradient {
        GradientStop { position: 0.0; color: "white" }
        GradientStop { position: 0.5; color: "#dddddd" }
        GradientStop { position: 1.0; color: "white" }
    }
    //signal quickAddRequested

    signal displayDatePickerAt(string field, int x, int y);
    signal displayContextPickerAt(string contextType, int x, int y);

    Keys.enabled: true
    Keys.onCancelPressed: QtHandler.CloseButtonClicked();
    Keys.onEscapePressed: QtHandler.CloseButtonClicked();
    Keys.onEnterPressed: {
        reviewAllDataForChanges()
    }

    function updatePanelSelection() {
        // load panel for item type
        // T = Task
        // L = List

        if (windowDisplaysItemOfType == "T") detailsPanel.selectTab(0)
        else detailsPanel.selectTab(1)
    }

    function setProjectTitle(title) {
        projectTag.text = qsTr("Add to: ") + title;
    }

    function activateInputFocus() {
        console.debug("QML++++ activateInputFocus")

        updatePanelSelection();
    }

    function doOp(opcode, operation) {
        console.debug("doOp: " + opcode);

        QtHandler.closeAllPicker();

        if (opcode === "clear") {
            if (tab0.isSelected) {
                titleInput.text = "";
                commentInput.text = "";

                QtHandler.removeQuickAddTemps()

                QtHandler.dateChanged("review_dt", "")
                QtHandler.dateChanged("start_dt", "")
                QtHandler.dateChanged("end_dt", "")

            } else if (tab1.isSelected) {
                textField.text = "";
            }

        } else if (opcode === "add") {
            if (tab0.isSelected) {
                QtHandler.quickAddTaskRequested(titleInput.text, commentInput.text)

            } else if (tab1.isSelected) {
                QtHandler.quickAddRequested(textField.text);
                textField.text = "";
            }
        }
    }


    Rectangle {
        id: windowRect
        color: "transparent"

        radius: xaWindowTitleBar.radius
        smooth: true
        anchors.fill: parent
        anchors.rightMargin: (maincomponent.platformID == "WIN" ? 1 : 0)
        anchors.bottomMargin: (maincomponent.platformID == "WIN" ? 1 : 0)

        //
        // window title bar
        //

        XAWindowTitleBar {
            id: xaWindowTitleBar
            windowTitle: maincomponent.windowTitle
            windowGotFocus: maincomponent.windowGotFocus
            windowDrawBorder: (maincomponent.platformID == "WIN")
            platformID: maincomponent.platformID
        }

        Rectangle {
            id: detailsPanel
            anchors.fill: parent
            anchors.leftMargin: 4
            anchors.rightMargin: 4
            anchors.topMargin: 20
            anchors.bottomMargin: 40

            color: "white"

            property int tabWidths: 80
            property int tabHeights: 21
            property int tabCount: 2

            property int tabStartPos: (detailsPanel.width / 2 - (detailsPanel.tabCount * detailsPanel.tabWidths / 2))

            function selectTab(tab) {
                tab0.isSelected = false
                tab1.isSelected = false

                QtHandler.closeAllPicker();

                if (tab === 0) {
                    tab0.isSelected = true;

                    tabTaskInputEditor.visible = true;
                    tabListInputEditor.visible = false;

                    titleInput.focus = true
                    titleInput.forceActiveFocus()

                } else if (tab === 1) {
                    tab1.isSelected = true

                    tabTaskInputEditor.visible = false;
                    tabListInputEditor.visible = true;

                    //textField.focus = true
                    //textField.forceActiveFocus()
                    textField.activateFocus()
                }
            }

            AIInspectorTabPanelTab {
                id: tab0
                anchors.top: parent.top
                height: detailsPanel.tabHeights
                width: detailsPanel.tabWidths
                anchors.left: parent.left
                anchors.leftMargin: detailsPanel.tabStartPos

                backgroundColor: "transparent"
                selectionColor: tabPanelMarkerColor

                text: qsTr("Task")
                isSelected: true

                onTriggered: {
                    //console.debug("Note triggered.")
                    detailsPanel.selectTab(0)
                }
            }

            AIInspectorTabPanelTab {
                id: tab1
                anchors.top: parent.top
                height: detailsPanel.tabHeights
                width: detailsPanel.tabWidths
                anchors.left: parent.left
                anchors.leftMargin: detailsPanel.tabStartPos + width

                backgroundColor: "transparent"
                selectionColor: tabPanelMarkerColor

                text: qsTr("List")

                onTriggered: {
                    //console.debug("Review triggered.")
                    detailsPanel.selectTab(1)
                }
            }

            Rectangle {
                id: tabPanelBaseLine
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.topMargin: detailsPanel.tabHeights
                anchors.right: parent.right
                height: 1

                color: tabPanelMarkerColor
            }

            Rectangle {
                id: tabPanelBottomLine
                anchors.left: parent.left
                anchors.bottom: parent.bottom
                anchors.right: parent.right
                height: 1

                color: tabPanelMarkerColor
            }

            Rectangle {
                id: tabPanelContentRect
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 1
                anchors.top: parent.top
                anchors.topMargin: detailsPanel.tabHeights+1

                gradient: tabPanelBackgroundGradient

                Item {
                    id: tabTaskInputEditor
                    anchors.fill: parent

                     property int inputInset: 8

                    //
                    // PANEL: Add Task
                    //
                    AIActionDetailsLineInput {
                        id: titleInput
                        anchors { left: parent.left; leftMargin: tabTaskInputEditor.inputInset; right: parent.right; rightMargin:tabTaskInputEditor.inputInset; top: parent.top; topMargin: 2 }
                        height: 21

                        itemLabelText: qsTr("Title:")
                        itemShowLabel: false
                        lineInputType: 0
                        inputInset: 0
                        itemPlaceholder: qsTr("Title")
                        itemText: maincomponent.itemTitle

                        onTextUpdated: {
                            console.debug("Title in Add Task Panel changed to: ")
                            console.debug(newText)
                            //locationUpdated(newText)
                        }

                        onItemClicked: {
                            console.debug("Title clicked - closing Picker")
                            QtHandler.closeAllPicker();
                        }
                    }

                    AIActionDetailsLineInput {
                        id: contextInput
                        anchors { left: parent.left; leftMargin: tabTaskInputEditor.inputInset; right: parent.right; rightMargin:titleInput.width/2+tabTaskInputEditor.inputInset; top: titleInput.bottom; topMargin: 0 }
                        height: 21

                        itemLabelText: qsTr("Context:")
                        itemShowLabel: false
                        lineInputType: 2
                        inputInset: 0
                        itemText: maincomponent.itemContextHR

                        //visible: false

                        onDisplayContextPickerAt: {
                            console.debug("Context Picker requested in Review Panel")
                            QtHandler.displayContextPickerAt(contextType, contextInput.x + contextInput.width - 6, contextInput.y + 44)
                        }
                    }

                    AIActionDetailsLineInput {
                        id: nextReviewInput
                        anchors { left: contextInput.right; leftMargin: 0; right: parent.right; rightMargin:tabTaskInputEditor.inputInset; top: titleInput.bottom; topMargin: 0 }
                        height: 21

                        itemLabelText: qsTr("Next Review:")
                        itemShowLabel: false
                        lineInputType: 1
                        inputInset: 0
                        itemText: maincomponent.itemDTSHR

                        onDateUpdated: {
                            console.debug("Next Review Date in Review Panel changed to: ")
                            console.debug(newSQLDate)
                            //commentUpdated(newComment)
                        }

                        onDisplayDatePickerAt: {
                            console.debug("Date Picker requested in Review Panel")
                            QtHandler.displayDatePickerAt("review_dt", nextReviewInput.x + nextReviewInput.width - 6, nextReviewInput.y + 44)
                        }
                    }

                    AIActionDetailsCommentInput {
                        id: commentInput
                        anchors { left: parent.left; right: parent.right; top: contextInput.bottom; topMargin: 4 }
                        height: 104

                        itemPlaceholder: qsTr("Comment")

                        onUpdated: {
                            console.debug("Comment in Review Panel changed to: ")
                            console.debug(newComment)
                            commentUpdated(newComment)
                        }

                        onItemClicked: {
                            console.debug("Comment clicked - closing Picker")
                            QtHandler.closeAllPicker();
                        }
                    }

                }

                Item {
                    id: tabListInputEditor
                    anchors.fill: parent

                    //
                    // PANEL: Add Task List
                    //
                    AIActionDetailsListInput {
                        id: textField
                        anchors { left: parent.left; leftMargin: 12; right: parent.right; rightMargin: 12; top: parent.top; topMargin: 4; bottom: parent.bottom ; bottomMargin: 8}

                        itemPlaceholder: qsTr("Enter one task per line")

                        onUpdated: {
                            console.debug("Task List in Quick Add Panel changed to: ")
                            console.debug(newComment)
                            commentUpdated(newComment)
                        }
                    }
                }

            }
        }

        Rectangle {
            id: projectTag

            anchors.left: parent.left
            anchors.leftMargin: 14
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 14

            property string text;

            onTextChanged: {
                buttonText.text = text
            }

            Text {
                id: buttonShadow
                anchors.left: parent.left
                anchors.bottom: parent.bottom

                font.family: buttonText.font.family
                font.pixelSize: buttonText.font.pixelSize
                smooth: true

                color: "black"

                text: buttonText.text
            }

            Text {
                id: buttonText
                anchors.left: parent.left
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 1

                font.family: "Arial"
                font.pixelSize: 12
                smooth:true

                color: "white"
            }
        }

        XAQMLButton {
            id: addButton
            operation: qsTr("Add")
            opcode: "add"

            anchors.right: parent.right
            anchors.rightMargin: 14
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 12
            width: 80
            height: 22

            framed: true
            macStyle: (maincomponent.platformID == "WIN" ? false : true)
        }

        XAQMLButton {
            id: hideButton
            operation: qsTr("Clear")
            opcode: "clear"

            anchors.right: addButton.left
            anchors.rightMargin: 12
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 12
            width: 80
            height: 22

            framed: true
            macStyle: (maincomponent.platformID == "WIN" ? false : true)
        }

        Component.onCompleted: {
            updatePanelSelection();
            setProjectTitle("Inbox")
        }
    }
}
